"""Provide version and author details."""


__title__ = "steelconnection"
__description__ = "Simplify access to the Riverbed SteelConnect REST API."
__version__ = "1.0.0"
__author__ = "Greg Mueller"
__author_email__ = "steelconnection@grelleum.com"
__copyright__ = "Copyright 2018 Greg Mueller"
__license__ = "MIT"
__url__ = "https://github.com/grelleum/SteelConnection"
__documentation__ = "https://steelconnection.readthedocs.io/"
